Learn R Programming

esviz (version 0.0.2)

VizPDFsOLE: Plotting two probability density gaussian functions and the optimal linear estimation (OLE) as result of combining them.

Description

This function plots two probability density gaussian functions and the optimal linear estimation (OLE) as result of combining them.

Usage

VizPDFsOLE(
  pdf_1,
  pdf_2,
  nsigma = 3,
  legendPos = "bottom",
  legendSize = 1,
  fileout = NULL,
  plotfile = NULL,
  width = 30,
  height = 15,
  units = "cm",
  dpi = 300
)

Value

VizPDFsOLE() returns a ggplot object containing the plot.

Arguments

pdf_1

A numeric array with a dimension named 'statistic', containg two parameters: mean' and 'standard deviation' of the first gaussian pdf to combining.

pdf_2

A numeric array with a dimension named 'statistic', containg two parameters: mean' and 'standard deviation' of the second gaussian pdf to combining.

nsigma

(optional) A numeric value for setting the limits of X axis. (Default nsigma = 3).

legendPos

(optional) A character value for setting the position of the legend ("bottom", "top", "right" or "left")(Default 'bottom').

legendSize

(optional) A numeric value for setting the size of the legend text. (Default 1.0).

fileout

(optional) A filename where the plot will be saved. (Default: the plot is not saved).

plotfile

Deprecated. Use 'fileout' instead

width

(optional) A numeric value indicating the plot width in units ("in", "cm", or "mm"). (Default width = 30).

height

(optional) A numeric value indicating the plot height. (Default height = 15).

units

(optional) A character value indicating the plot size unit. (Default units = 'cm').

dpi

(optional) A numeric value indicating the plot resolution. (Default dpi = 300).

Author

Eroteida Sanchez-Garcia - AEMET, esanchezg@aemet.es

Examples

Run this code
pdf_1 <- c(1.1,0.6)
attr(pdf_1, "name") <- "NAO1"
dim(pdf_1) <-  c(statistic = 2)
pdf_2 <- c(1,0.5)
attr(pdf_2, "name") <- "NAO2"
dim(pdf_2) <-  c(statistic = 2)

VizPDFsOLE(pdf_1, pdf_2)

Run the code above in your browser using DataLab