- data
Array with three named dimensions: 'dimx', 'dimy', 'dimcat',
containing the values to be displayed in a coloured image with triangles.
- brks
A vector of the color bar intervals. The length must be one more
than the parameter 'cols'. Use ColorBar() to generate default values.
- cols
A vector of valid colour identifiers for color bar. The length
must be one less than the parameter 'brks'. Use ColorBar() to generate
default values.
- toptitle
A string of the title of the grid. Set NULL as default.
- sig_data
Logical array with the same dimensions as 'data' to add layers
to the plot. A value of TRUE at a grid cell will draw a dot/symbol on the
corresponding triangle of the plot. Set NULL as default.
- pch_sig
Symbol to be used to represent sig_data. Takes 18
(diamond) by default. See 'pch' in par() for additional accepted options.
- col_sig
Colour of the symbol to represent sig_data.
- cex_sig
Parameter to increase/reduce the size of the symbols used
to represent sig_data.
- xlab
A logical value (TRUE) indicating if xlabels should be plotted
- ylab
A logical value (TRUE) indicating if ylabels should be plotted
- xlabels
A vector of labels of the x-axis The length must be
length of the col of parameter 'data'. Set the sequence from 1 to the
length of the row of parameter 'data' as default.
- xtitle
A string of title of the x-axis. Set NULL as default.
- ylabels
A vector of labels of the y-axis The length must be
length of the row of parameter 'data'. Set the sequence from 1 to the
length of the row of parameter 'data' as default.
- ytitle
A string of title of the y-axis. Set NULL as default.
- drawleg
A logical value to decide to draw the color bar legend or not.
Set TRUE as default.
- legend
Deprecated. Use 'drawleg' instead.
- lab_legend
A vector of labels indicating what is represented in each
category (i.e. triangle). Set the sequence from 1 to the length of
the categories (2 or 4).
- cex_leg
A number to indicate the increase/reductuion of the lab_legend
used to represent sig_data.
- col_leg
Color of the legend (triangles).
- cex_axis
A number to indicate the increase/reduction of the axis labels.
- mar
A numerical vector of the form c(bottom, left, top, right) which
gives the number of lines of margin to be specified on the four sides of the
plot.
- fileout
A string of full directory path and file name indicating where
to save the plot. If not specified (default), a graphics device will pop up.
- size_units
A string indicating the units of the size of the device
(file or window) to plot in. Set 'px' as default. See ?Devices and the
creator function of the corresponding device.
- res
A positive number indicating resolution of the device (file or
window) to plot in. See ?Devices and the creator function of the
corresponding device.
- figure.width
a numeric value to control the width of the plot.
- ...
The additional parameters to be passed to function
ColorBarContinuous() in for color legend creation.