- pdf_1
A numeric array with a dimension named 'statistic', containg
two parameters: mean' and 'standard deviation' of the first gaussian pdf
to combining.
- pdf_2
A numeric array with a dimension named 'statistic', containg
two parameters: mean' and 'standard deviation' of the second gaussian pdf
to combining.
- nsigma
(optional) A numeric value for setting the limits of X axis.
(Default nsigma = 3).
- legendPos
(optional) A character value for setting the position of the
legend ("bottom", "top", "right" or "left")(Default 'bottom').
- legendSize
(optional) A numeric value for setting the size of the
legend text. (Default 1.0).
- fileout
(optional) A filename where the plot will be saved.
(Default: the plot is not saved).
- plotfile
Deprecated. Use 'fileout' instead
- width
(optional) A numeric value indicating the plot width in
units ("in", "cm", or "mm"). (Default width = 30).
- height
(optional) A numeric value indicating the plot height.
(Default height = 15).
- units
(optional) A character value indicating the plot size
unit. (Default units = 'cm').
- dpi
(optional) A numeric value indicating the plot resolution.
(Default dpi = 300).